@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.c,v 1.124 2006/01/09 11:38:27 pborelli Exp $
+ * $Id: gedit-document.c,v 1.126 2006/01/19 18:16:00 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,7 +76,6 @@ PROFILE (static GTimer *timer = NULL);
 
 static void	gedit_document_set_readonly	(GeditDocument *doc,
 						 gboolean       readonly);
-
 static void	to_search_region_range 		(GeditDocument *doc,
 						 GtkTextIter   *start, 
 						 GtkTextIter   *end);
@@ -91,7 +90,6 @@ static void	delete_range_cb 		(GeditDocument *doc,
 			     
 struct _GeditDocumentPrivate
 {
-	gint	     auto_save : 1;
 	gint	     readonly : 1;
 	gint	     last_save_was_manually : 1; 	
 	gint	     language_set_by_user : 1;
@@ -108,9 +106,6 @@ struct _GeditDocumentPrivate
 
 	gchar	    *mime_type;
 
-	gint	     auto_save_interval;
-	guint	     auto_save_timeout;
-
 	time_t       mtime;
 
 	GTimeVal     time_of_last_save_or_load;
@@ -214,9 +209,6 @@ gedit_document_finalize (GObject *object)
 	
 	gedit_debug (DEBUG_DOCUMENT);
 
-	if (doc->priv->auto_save_timeout > 0)
-		g_source_remove (doc->priv->auto_save_timeout);
-
 	if (doc->priv->untitled_number > 0)
 	{
 		g_return_if_fail (doc->priv->uri == NULL);
@@ -639,13 +631,6 @@ gedit_document_init (GeditDocument *doc)
 	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (doc), 
 					      gedit_prefs_manager_get_bracket_matching ());
 
-	doc->priv->auto_save = gedit_prefs_manager_get_auto_save ();
-	doc->priv->auto_save = (doc->priv->auto_save != FALSE);
-
-	doc->priv->auto_save_interval = gedit_prefs_manager_get_auto_save_interval ();
-	if (doc->priv->auto_save_interval <= 0)
-		doc->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
-
 	gedit_document_set_enable_search_highlighting (doc,
 						       gedit_prefs_manager_get_enable_search_highlighting ());
 
@@ -711,15 +696,23 @@ set_uri (GeditDocument *doc,
 	{
 		gchar *base_name;
 
-		/* Set the mime type using the file extension or "text/plain" 
-	   	 * if no match. */
+		/* Guess the mime type from file extension or fallback to "text/plain" */
 		base_name = gnome_vfs_uri_extract_short_path_name (doc->priv->vfs_uri);
-		if (base_name != NULL) 
-			doc->priv->mime_type = g_strdup ("text/plain"); // FIXME
-//			gnome_vfs_mime_type_from_name_or_default (base_name,
-//								  "text/plain");
+		if (base_name != NULL)
+		{
+			const gchar *detected_mime;
+
+			detected_mime = gnome_vfs_get_mime_type_for_name (base_name);
+			if (detected_mime == NULL ||
+			    strcmp (GNOME_VFS_MIME_TYPE_UNKNOWN, detected_mime) == 0)
+				detected_mime = "text/plain";
+
+			doc->priv->mime_type = g_strdup (detected_mime);
+		}
 		else
+		{
 			doc->priv->mime_type = g_strdup ("text/plain");
+		}
 
 		g_free (base_name);
 	}
@@ -883,28 +876,6 @@ set_readonly (GeditDocument *doc,
 	
 	readonly = (readonly != FALSE);
 
-	if (readonly) 
-	{
-		if (doc->priv->auto_save_timeout > 0)
-		{
-			g_source_remove (doc->priv->auto_save_timeout);
-			doc->priv->auto_save_timeout = 0;
-		}
-	}
-	else
-	{
-		if (doc->priv->auto_save &&
-		    (doc->priv->auto_save_timeout <= 0) && 
-                    !gedit_document_is_untitled (doc))
-		{
-/*			doc->priv->auto_save_timeout = g_timeout_add
-				 (doc->priv->auto_save_interval * 1000 * 60,
-		 		 (GSourceFunc)gedit_document_auto_save,
-		  		 doc);
-*/
-		}
-	}
-
 	if (doc->priv->readonly == readonly) 
 		return;
 
@@ -1249,6 +1220,7 @@ gedit_document_is_untitled (GeditDocument *doc)
 	return (doc->priv->uri == NULL);
 }
 
+
 gboolean
 gedit_document_get_deleted (GeditDocument *doc)
 {
@@ -1678,35 +1650,6 @@ gedit_document_get_encoding (GeditDocument *doc)
 	return doc->priv->encoding;
 }
 
-void
-gedit_document_set_auto_save_enabled (GeditDocument *doc, 
-				      gboolean       enable)
-{
-	gedit_debug (DEBUG_DOCUMENT);
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-	enable = (enable != FALSE);
-	
-	// TODO
-	
-	return;
-}
-
-void
-gedit_document_set_auto_save_interval (GeditDocument *doc, 
-				       gint           interval)
-{
-	gedit_debug (DEBUG_DOCUMENT);
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (interval > 0);
-
-	// TODO
-
-	return;
-}
-
 glong
 _gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 {
